@@ -12,6 +12,9 @@ def get_result(text,
                grammar_dice=GRAMMAR_DICE,
                grammar_calc=GRAMMAR_CALCULATOR) -> List:
     results = []
+    for recursion in findall(r"\(([^\(\)]+)\)", text):
+        text = text.replace(f"({recursion})",
+                            str(sum(el.total for el in get_result(recursion, grammar_dice=grammar_dice, grammar_calc=grammar_calc))))
     repeats_math = search(r"(^\d+)[хx]|[хx](\d+$)", text)
     repeats = repeats_math.group(1) or repeats_math.group(2) if repeats_math else 1
     for _ in range(int(repeats) if int(repeats) < 10 else 10):
